# Push message

This package can push messages to specified users through different servers.

# Supported servers

- [x] QYWX(企业微信)
- [ ] webhook

# Usage

## QYWX

使用企业微信推送消息，需要获取corpid和secret，获取方式请参考：[https://developer.work.weixin.qq.com/document/path/90665](https://developer.work.weixin.qq.com/document/path/90665)

